@@ -1,8 +1,20 @@
+#
+# This file is part of Redis
+#
+# This software is Copyright (c) 2013 by Pedro Melo, Damien Krotkine.
+#
+# This is free software, licensed under:
+#
+#   The Artistic License 2.0 (GPL Compatible)
+#
 package Redis::Hash;
+{
+  $Redis::Hash::VERSION = '1.963';
+}
 
 # ABSTRACT: tie Perl hashes to Redis hashes
-our $VERSION = '1.962'; # VERSION
-our $AUTHORITY = 'cpan:MELO'; # AUTHORITY
+# VERSION
+# AUTHORITY
 
 use strict;
 use warnings;
@@ -65,22 +77,17 @@ sub CLEAR {
 
 1;    ## End of Redis::Hash
 
-
-
 __END__
+
 =pod
 
-=encoding utf-8
-
-=for :stopwords Pedro Melo Damien Krotkine Melo, ACKNOWLEDGEMENTS
-
 =head1 NAME
 
 Redis::Hash - tie Perl hashes to Redis hashes
 
 =head1 VERSION
 
-version 1.962
+version 1.963
 
 =head1 DESCRIPTION
 
@@ -132,4 +139,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
